==> keybase-2.8.0.tar.gz: client-2.8.0/shared/wallets/send-form/choose-asset/container.js <==
// @flow
import ChooseAsset, {type DisplayItem, type OtherItem} from '.'
import {compose, connect, lifecycle, setDisplayName} from '../../../util/container'
import * as WalletsGen from '../../../actions/wallets-gen'
import * as Constants from '../../../constants/wallets'
import * as Types from '../../../constants/types/wallets'
import type {NavigateUpPayload} from '../../../actions/route-tree-gen'

type OwnProps = {
  navigateUp?: () => NavigateUpPayload, // if routed
  onBack?: () => void, // if direct
}

const mapStateToProps = state => {
  const accountID = state.wallets.selectedAccount
  const to = state.wallets.building.to
  const selected = state.wallets.building.currency

  return {
    accountID,
    to,
    selected,
    currencies: Constants.getDisplayCurrencies(state).toArray(),
    sendAssets: state.wallets.building.sendAssetChoices,
  }
}

const mapDispatchToProps = (dispatch, {navigateUp, onBack}: OwnProps) => ({
  _refresh: (accountID: Types.AccountID, to: string) => {
    dispatch(WalletsGen.createLoadDisplayCurrencies())
    dispatch(WalletsGen.createLoadSendAssetChoices({from: accountID, to}))
  },
  _onClose: () => {
    navigateUp ? dispatch(navigateUp()) : onBack && onBack()
  },
  _onChoose: (currency: string) => {
    dispatch(WalletsGen.createSetBuildingCurrency({currency}))
    navigateUp ? dispatch(navigateUp()) : onBack && onBack()
  },
})

const mergeProps = (stateProps, dispatchProps, ownProps) => ({
  ...stateProps,
  ...ownProps,
  displayChoices: (stateProps.currencies || []).map(c => ({
    currencyCode: c.code,
    selected: c.code === stateProps.selected,
    symbol: c.symbol,
    type: 'display choice',
  })),
  otherChoices: (stateProps.sendAssets || []).map(a => ({
    currencyCode: a.asset.code,
    selected: a.asset.code === stateProps.selected,
    disabledExplanation: a.subtext || 'Support for other assets coming soon',
    issuer: a.asset.issuer,
    type: 'other choice',
  })),
  refresh: () => dispatchProps._refresh(stateProps.accountID, stateProps.to),
  onBack: () => dispatchProps._onClose(),
  onClose: () => dispatchProps._onClose(),
  onChoose: (item: DisplayItem | OtherItem) => dispatchProps._onChoose(item.currencyCode),
})

export default compose(
  connect(
    mapStateToProps,
    mapDispatchToProps,
    mergeProps
  ),
  lifecycle({
    componentDidMount() {
      this.props.refresh()
    },
  }),
  setDisplayName('ChooseAsset')
)(ChooseAsset)

==> keybase-2.11.0.tar.gz: client-2.11.0/shared/wallets/send-form/choose-asset/container.js <==
// @flow
import ChooseAsset, {type DisplayItem, type OtherItem} from '.'
import {namedConnect, type RouteProps} from '../../../util/container'
import * as WalletsGen from '../../../actions/wallets-gen'
import * as Constants from '../../../constants/wallets'
import * as Types from '../../../constants/types/wallets'

type OwnProps = RouteProps<{}, {}>

const mapStateToProps = state => {
  const accountID = state.wallets.selectedAccount
  const to = state.wallets.building.to
  const selected = state.wallets.building.currency

  return {
    accountID,
    currencies: Constants.getDisplayCurrencies(state).toArray(),
    selected,
    sendAssets: state.wallets.building.sendAssetChoices,
    to,
  }
}

const mapDispatchToProps = (dispatch, {navigateUp, onBack}: OwnProps) => ({
  _onChoose: (currency: string) => {
    dispatch(WalletsGen.createSetBuildingCurrency({currency}))
    dispatch(navigateUp())
  },
  _onRefresh: (accountID: Types.AccountID, to: string) => {
    dispatch(WalletsGen.createLoadDisplayCurrencies())
    accountID !== Types.noAccountID && dispatch(WalletsGen.createLoadSendAssetChoices({from: accountID, to}))
  },
  onBack: () => dispatch(navigateUp()),
})

const mergeProps = (stateProps, dispatchProps, ownProps) => ({
  displayChoices: (stateProps.currencies || []).map(c => ({
    currencyCode: c.code,
    selected: c.code === stateProps.selected,
    symbol: c.symbol,
    type: 'display choice',
  })),
  onBack: dispatchProps.onBack,
  onChoose: (item: DisplayItem | OtherItem) => dispatchProps._onChoose(item.currencyCode),
  onRefresh: () => dispatchProps._onRefresh(stateProps.accountID, stateProps.to),
  otherChoices: (stateProps.sendAssets || []).map(a => ({
    currencyCode: a.asset.code,
    disabledExplanation: a.subtext || 'Support for other assets coming soon',
    issuer: a.asset.issuer,
    selected: a.asset.code === stateProps.selected,
    type: 'other choice',
  })),
  selected: stateProps.selected,
})

export default namedConnect<OwnProps, _, _, _, _>(
  mapStateToProps,
  mapDispatchToProps,
  mergeProps,
  'ChooseAsset'
)(ChooseAsset)
